@@ -20,11 +20,6 @@ load_dotenv(env_path)
 
 def _check_all_environment_variables_are_set():
     environment_variables = ["ODS_API_KEY",
-                             "USE_PROXY",
-                             "PROXY_USER",
-                             "PROXY_PASSWORD",
-                             "PROXY_ADDRESS",
-                             "PROXY_PORT",
                              "ODS_DOMAIN",
                              "ODS_API_TYPE"]
 
@@ -57,26 +52,3 @@ def _get_headers():
     _api_key = os.getenv('ODS_API_KEY')
     _headers = {'Authorization': f'apikey {_api_key}'}
     return _headers
-
-def _get_proxies() -> dict[str, str]:
-    use_proxy = os.getenv("USE_PROXY")
-    if use_proxy.lower() == 'false':
-        proxies = None
-
-    elif use_proxy.lower() == 'true':
-        proxy_user = os.getenv("PROXY_USER")
-        proxy_password = os.getenv("PROXY_PASSWORD")
-        proxy_address = os.getenv("PROXY_ADDRESS")
-        proxy_port = os.getenv("PROXY_PORT")
-
-        proxy = f"http://{proxy_user}:{proxy_password}@{proxy_address}:{proxy_port}/"
-        proxies = {
-            "http": proxy,
-            "https": proxy,
-        }
-
-    else:
-        raise ValueError(f"The value USE_PROXY in the .ods_utils_py.env is {use_proxy}, but should be 'true' or 'false' "
-                         f"(case insensitive)")
-
-    return proxies
